from setuptools import setup, find_packages

setup(
    name='testsing',
    version='0.0.1',
    author='ZhangPeng',
    author_email='apyizhidouzai@163.com',
    description='A useless test tool',
    packages=find_packages()
)